@@ -303,8 +303,8 @@ class accDisplay (hildon.Window):
 	def on_about(self, *args):
 		dialog = gtk.AboutDialog()
 		dialog.set_name("accDisplay")
-		
-		dialog.set_comments('Accelerometers View/Dataloggin')
+		dialog.set_logo_icon_name("accDisplay")
+		dialog.set_comments('Accelerometers View/Record/Playback')
 		dialog.set_version("0.1")
 		dialog.set_copyright("By Clovis Peruchi Scotti (aka cpscotti)")
 		dialog.set_website("www.das.ufsc.br/~scotti")
